# computer_vision_workshop

Source Code of Computer Vision Workshop
OpenCV
Python
C++
Farshid PirahanSiah, PhD.                        August 2019 



Computer Vision: OpenCV
Deep Learning:     TensorFlow, PyTorch, Caffe, Torch 
Optimization:     OpenVINO, OpenCL, CUDA
Language:         C++, Python

pip install -i https://test.pypi.org/simple/ farshid 
